classdef C2boundary
    % Abstract class for C2-smooth closed boundary.
    
    properties
        points % coordinates of boundary points, an array of dimension 2 X nbPoints
        tvec % tangent vector
        tvec_norm % norm of the tangent vector
        avec % acceleration vector
        normal % outward normal vector
        nbPoints % number of boundary points
        sigma % element of curve integration.
    end
    
    methods
        function obj = C2boundary(points, tvec, avec)
            % Initialization of C2boundary object:
            % Inputs:
            % points: coordinates of boundary point, a 2 x nbPoints array
            % tvec: tangent vectors of boundary point, a 2 x nbPoints array
            % avec: acceleration vectors, a 2 x nbPoints array
            
            obj.points = points;
            obj.tvec = tvec;
            obj.avec = avec;
            
            normal = [0, 1; -1, 0]*tvec ; %orthogonal to tvec
            tt = sqrt(normal(1,:).^2+normal(2,:).^2);
            obj.normal = normal ./ repmat(tt,2,1); %normalized
            
            obj.nbPoints = size(points, 2);
            obj.tvec_norm = sqrt( obj.tvec(1,:).^2 + obj.tvec(2,:).^2 );
            obj.sigma = 2*pi / obj.nbPoints * obj.tvec_norm;
        end
        
        function plot(obj,varargin)
            % loop the curve
            X = [obj.points(1,:) , obj.points(1,1)];
            Y = [obj.points(2,:) , obj.points(2,1)];
            plot(X, Y, varargin{:});
        end
    end
end

